aboutsummaryrefslogtreecommitdiff
path: root/src/nvim/message.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/nvim/message.c')
-rw-r--r--src/nvim/message.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/nvim/message.c b/src/nvim/message.c
index 3163a797ed..637b89ccbe 100644
--- a/src/nvim/message.c
+++ b/src/nvim/message.c
@@ -2030,9 +2030,10 @@ static int do_more_prompt(int typed_char)
int i;
// We get called recursively when a timer callback outputs a message. In
- // that case don't show another prompt. Also when at the hit-Enter prompt.
- if (entered || State == HITRETURN) {
- return false;
+ // that case don't show another prompt. Also when at the hit-Enter prompt
+ // and nothing was typed.
+ if (entered || (State == HITRETURN && typed_char == 0)) {
+ return false;
}
entered = true;